#!/bin/bash
## ------------------------------------------------------------------
## SCRIPT PARA LA DESCARGA AUTOMATICA DE NOTICIAS CON EL CRAWLER
## ------------------------------------------------------------------


site_section=( otros_sitios sitios_yucatan )
other_site_list=( diarioYaqui laJornada laJornadaAgs laJornadaBC laJornadaGro laJornadaMaya laJornadaOte laJornadaSanLuis laJornadaVer laJornadaZac )
yuc_site_list=( alChile desdeElBalcon diarioYucatan grilloPorteno laVerdadYuc lectorMX miPuntoDeVista notirivas notisureste puntoMedio sona893 yucatanALaMano yucatanAlMinuto yucatanEnCorto )

base_path=$HOME/crawler/
cd $base_path                    # activando el venv (entorno virtual) del crawler
source bin/activate

PATH=$PATH:$HOME/crawler/bin/python:$HOME/crawler/bin/scrapy       # rutas donde se encuentran el scrapy y python
export PATH


## CALCULO DEL NUMERO DE DIAS PARA DESCARGAR NOTICIAS -------------------------
function obtain_days() {
	local last_date=$1          # parametro 1
	local stop_date=$2	        # parametro 2


	local day_date_1=`date -d "$last_date" '+%j'`      # numero del dia del anio de la fecha en "last_date"
	local y1=`date -d "$last_date" '+%Y'`
	local day_date_2=`date -d "$stop_date" '+%j'`
	local y2=`date -d "$stop_date" '+%Y'`


	if [ $y1 -eq $y2 ]  # si $y1 es igual a $y2
	then
		local num_days=$(expr $day_date_2 - $day_date_1)
	elif [ $y1 -lt $y2 ]
	then
		local days_date_1=0
		for year in `seq $y1 $y2`
		do
			if [ $year -eq $y1 ]
			then
				local days_date=$(expr `date -d "$y1-12-31" '+%j'` - $day_date_1)
			elif [ $year -eq $y2 ]
			then
				days_date=$day_date_2
			else
				days_date=`date -d "$year-12-31" '+%j'`
			fi
			days_date_1=$(expr $days_date_1 + $days_date)
		done
		local num_days=$(expr $days_date_1)
	fi

	return $num_days
}
## ----------------------------------------------------------------------------


## SECUENCIA DE DESCARGA DE NOTICIAS --------------------------------------------------------------

for section in ${site_section[@]}
do
	if [ $section = otros_sitios ]
	then
		list=${other_site_list[@]}
	else
		list=${yuc_site_list[@]}
	fi

	for site in $list
	do
		## POR CADA SITIO ENCUENTRA EL ARCHIVO CON LA ULTIMA FECHA EN QUE SE DESCARGO NOTICIAS ----
		cd crawledJsonFiles/$section/$site
		max=`ls | tail -1`           # obtiene el ultimo directorio

		cd $max
		json_file=`ls | tail -1`     # obtiene el ultimo archivo dentro del directorio
		## ----------------------------------------------------------------------------------------
		cd ~/crawler

		last_date=`date -d "${json_file%%.*}" '+%Y-%m-%d'`
		stop_date=`date -d "now" '+%Y-%m-%d'`        # descarga hasta una fecha antes de esta
		## NOTA: Para que descargue hasta una fecha antes, el paro debe fijarse una fecha despues. Por eso 'stop_date' se fija con 'now'.

		if [ $last_date != $stop_date ]
		then
			last_date=`date -d "$last_date +1 days" '+%Y-%m-%d'`                  

			## FUNCION 'obtain_days' CALCULA EL NUMERO DE DIAS ENTRE LA ULTIMA FECHA DE DESCARGA Y LA FECHA DE PARO
			obtain_days $last_date $stop_date    # parametros que se pasan a la funcion
			num_days=$?                          # retorno del valor por parte de la funcion 'obtain_days'

			for i in `seq $num_days -1 1`
			do
				y=`date -d "$stop_date - $i days" '+%Y'`
				m=`date -d "$stop_date - $i days" '+%m'`
				d=`date -d "$stop_date - $i days" '+%d'`
				
				cd cawlersNoticias/$section/$site/       # ruta donde se encuentran alojados los crawlers de cada sitio
				
				scrapy crawl noticias -t json -o $y-$m-$d.json -a year=$y -a month=$m -a day=$d      # ejecucion del crawler correspondiente segun el sitio
				[ -s $y-$m-$d.json ] || rm $y-$m-$d.json    # revisa si el archivo contiene informacion, sino lo elimina
			
				if [ -e $y-$m-$d.json ]                  # revisa si se genero el archivo json con las noticias
				then
					destination=$HOME/crawler/prueba/$section/$site/$y/      # ruta donde se guardaran los json generados
					
					if [ ! -d $destination ]             # si no existe la ruta de destino la crea
					then
						mkdir -p $destination
					fi
					
					mv -f $y-$m-$d.json $destination     # mueve el archivo json a la ruta de destino
				fi

				cd ~/crawler
			done
		fi
	done
done

deactivate
## ------------------------------------------------------------------------------------------------